@@ -14,6 +14,5 @@ test_that("palette_this works with named palcolor but missed items", {
         palette = "Paired",
         palcolor = c("b" = "blue", "a" = "green")
     )
-    colors <- as.list(colors)[sort(names(colors))]
-    expect_equal(colors, list(a = "green", b = "blue"))
+    expect_equal(colors, c(a = "green", b = "blue", c = "#B2DF8A"))
 })
